--- title: "wallaroo.tag" type: docs linkTitle: "wallaroo.tag" ---
class Tag(wallaroo.object.Object):

Tags that may be attached to models and pipelines.

Tag( client: Optional[wallaroo.client.Client], data: Dict[str, Any], standalone=False)

Base constructor.

Each object requires:

- a GraphQL client - in order to fill its missing members dynamically
- an initial data blob - typically from unserialized JSON, contains at
- least the data for required members (typically the object's primary key) and optionally other data members.

def id(self) -> int:
def tag(*args, **kwargs):
def model_tags(*args, **kwargs):
def pipeline_tags(*args, **kwargs):
def list_models(self) -> List[wallaroo.model.Model]:

Lists the models this tag is on.

def add_to_model(self, model_id: int):
def remove_from_model(self, model_id: int):
def list_pipelines(self) -> List[wallaroo.pipeline.Pipeline]:

Lists the pipelines this tag is on.

def add_to_pipeline(self, pipeline_id: int):
def remove_from_pipeline(self, pipeline_id: int):
class Tags(typing.List[wallaroo.tag.Tag]):

Wraps a list of tags for display in a display-aware environment like Jupyter.

##### Inherited Members

builtins.list
  list
  clear
  copy
  append
  insert
  extend
  pop
  remove
  index
  count
  reverse
  sort